@@ -1,7 +1,7 @@
 import json
 import logging
 import os
-from typing import Callable, List, Union
+from typing import Callable, List, Optional, Union
 
 from kafka import KafkaConsumer
 
@@ -10,11 +10,13 @@ KAFKA_PORT = os.environ.get("KAFKA_PORT", "9092")
 KAFKA_API_VERSION = os.environ.get("KAFKA_API_VERSION", "2.5.0")
 
 
-def create_kafka_consumer(topics: Union[str, List[str]]) -> KafkaConsumer:
+def create_kafka_consumer(
+    group_id: Optional[str], topics: Union[str, List[str]]
+) -> KafkaConsumer:
     logging.info("Creating Kafka Consumer...")
     consumer = KafkaConsumer(
         bootstrap_servers=f"{KAFKA_HOST}:{KAFKA_PORT}",
-        group_id="datalake",
+        group_id=group_id,
         reconnect_backoff_max_ms=100000,  # TODO: what value to set here?
         # API Version is needed in order to prevent api version guessing leading to an error
         # on startup if Kafka Broker isn't ready yet
@@ -28,10 +30,11 @@ def create_kafka_consumer(topics: Union[str, List[str]]) -> KafkaConsumer:
 
 
 def consume_kafka(
+    group_id: Optional[str],
     topics: Union[str, List[str]],
     message_processing_func: Callable[[dict], None],
 ) -> None:
-    consumer = create_kafka_consumer(topics)
+    consumer = create_kafka_consumer(group_id, topics)
     logging.info("Ready to consume messages")
     for message in consumer:
         val_utf8 = message.value.decode("utf-8").replace("NaN", "null")
